#!/bin/sh
#
# source: http://kent.dl.sourceforge.net/sourceforge/freebob/libfreebob-1.0.11.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='libfreebob'
softversion='1.0.11'
packageversion='64.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
cat $buildir/libfreebob-1.0.11-includes.patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --disable-static

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL NEWS README TODO $dest/usr/doc/$soft-$softversion

#-----------------build directories and copy the build script

mkdir -p $dest/install
cat << EODESC >> $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

          |-----handy-ruler------------------------------------------------------|
libfreebob: libfreebob - BeBoB means the BridgeCo enhanced breakout box firmware
libfreebob:
libfreebob: FreeBoB is a driver for BeBoB which is the firmware. Currently,
libfreebob: there is only  one chip  in the  wild which is running this kind of 
libfreebob: software, the DM1000. But  it is  to  be  expected  to  find  soon
libfreebob: other chips (still prefix-labled with DM) which will running BeBoB
libfreebob: versions.
libfreebob:
libfreebob:
libfreebob:
libfreebob:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5